@@ -14,18 +14,28 @@ seeker_class_name = seeker_file_name.capitalize()
 hider_file_name = sys.argv[2]
 hider_class_name = hider_file_name.capitalize()
 
-code = [
-    f"from {seeker_file_name} import {seeker_class_name}",
-    f"from {hider_file_name} import {hider_class_name}",
-    f"match = Match({seeker_class_name}, {hider_class_name})",
-]
-exec("\n".join(code))
+debug_message = "Match run sucessfully"
+code_successful = True
+try:
+    code = [
+        f"from {seeker_file_name} import {seeker_class_name}",
+        f"from {hider_file_name} import {hider_class_name}",
+        f"match = Match({seeker_class_name}, {hider_class_name})",
+    ]
+    exec("\n".join(code))
+    match.run()
+except Exception as e:
+    debug_message = e
+    code_successful = False
 
-match.run()
 result_file_name = sys.argv[3]
 with open(f"{result_file_name}.json", "w") as f:
-    result = match.get_result()
+    result = {}
+    if code_successful:
+        result = match.get_result()
+
     result["seeker_name"] = sys.argv[1]
     result["hider_name"] = sys.argv[2]
-    json_str = json.dumps(match.get_result())
+    result["debug"] = debug_message
+    json_str = json.dumps(result)
     f.write(json_str)
\ No newline at end of file
